@@ -29,8 +29,8 @@ public:
       : AcceptedChanges(AcceptedChanges), Owner(Owner) {}
 
   /// \brief Entry point to the callback called when matches are made.
-  virtual void run(const clang::ast_matchers::MatchFinder::MatchResult &Result)
-      override;
+  void
+  run(const clang::ast_matchers::MatchFinder::MatchResult &Result) override;
 
 private:
   /// \brief Locates the \c auto_ptr token when it is referred by a \c TypeLoc.
@@ -88,8 +88,8 @@ public:
       : AcceptedChanges(AcceptedChanges), Owner(Owner) {}
 
   /// \brief Entry point to the callback called when matches are made.
-  virtual void run(const clang::ast_matchers::MatchFinder::MatchResult &Result)
-      override;
+  void
+  run(const clang::ast_matchers::MatchFinder::MatchResult &Result) override;
 
 private:
   unsigned &AcceptedChanges;
