@@ -34,8 +34,8 @@ public:
       : Transform("UseAuto", Options) {}
 
   /// \see Transform::run().
-  virtual int apply(const clang::tooling::CompilationDatabase &Database,
-                    const std::vector<std::string> &SourcePaths) override;
+  int apply(const clang::tooling::CompilationDatabase &Database,
+            const std::vector<std::string> &SourcePaths) override;
 };
 
 #endif // CLANG_MODERNIZE_USE_AUTO_H
