@@ -7,8 +7,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_CLANG_TOOLS_EXTRA_CLANG_TIDY_CLANG_TIDY_OPTIONS_H
-#define LLVM_CLANG_TOOLS_EXTRA_CLANG_TIDY_CLANG_TIDY_OPTIONS_H
+#ifndef LLVM_CLANG_TOOLS_EXTRA_CLANG_TIDY_CLANGTIDYOPTIONS_H
+#define LLVM_CLANG_TOOLS_EXTRA_CLANG_TIDY_CLANGTIDYOPTIONS_H
 
 #include "llvm/ADT/Optional.h"
 #include "llvm/ADT/StringMap.h"
@@ -95,7 +95,7 @@ public:
 
   /// \brief Returns options applying to a specific translation unit with the
   /// specified \p FileName.
-  virtual const ClangTidyOptions &getOptions(llvm::StringRef FileName) = 0;
+  virtual ClangTidyOptions getOptions(llvm::StringRef FileName) = 0;
 };
 
 /// \brief Implementation of the \c ClangTidyOptionsProvider interface, which
@@ -108,7 +108,7 @@ public:
   const ClangTidyGlobalOptions &getGlobalOptions() override {
     return GlobalOptions;
   }
-  const ClangTidyOptions &getOptions(llvm::StringRef /*FileName*/) override {
+  ClangTidyOptions getOptions(llvm::StringRef /*FileName*/) override {
     return DefaultOptions;
   }
 
@@ -187,7 +187,7 @@ public:
                       const ClangTidyOptions &OverrideOptions,
                       const ConfigFileHandlers &ConfigHandlers);
 
-  const ClangTidyOptions &getOptions(llvm::StringRef FileName) override;
+  ClangTidyOptions getOptions(llvm::StringRef FileName) override;
 
 private:
   /// \brief Try to read configuration files from \p Directory using registered
@@ -213,4 +213,4 @@ std::string configurationAsText(const ClangTidyOptions &Options);
 } // end namespace tidy
 } // end namespace clang
 
-#endif // LLVM_CLANG_TOOLS_EXTRA_CLANG_TIDY_CLANG_TIDY_OPTIONS_H
+#endif // LLVM_CLANG_TOOLS_EXTRA_CLANG_TIDY_CLANGTIDYOPTIONS_H
