@@ -17,6 +17,7 @@
 
 namespace clang {
 namespace tidy {
+namespace llvm {
 
 class LLVMModule : public ClangTidyModule {
 public:
@@ -33,6 +34,8 @@ public:
 static ClangTidyModuleRegistry::Add<LLVMModule> X("llvm-module",
                                                   "Adds LLVM lint checks.");
 
+} // namespace llvm
+
 // This anchor is used to force the linker to link in the generated object file
 // and thus register the LLVMModule.
 volatile int LLVMModuleAnchorSource = 0;
